@@ -6,7 +6,7 @@ use base qw/HTTP::MobileAttribute::Plugin/;
 sub new {
     my ($class, $config, $c) = @_;
     my $self = $class->SUPER::new($config, $c);
-    $c->load_plugins(map({ "Parser::$_" } qw/DoCoMo ThirdForce EZweb NonMobile AirHPhone/));
+    # $c->load_plugins();
     $self;
 }
 
